# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/trade_and_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import trade_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2
from systemathics.apis.type.shared.v1 import book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/trade_and_book.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5systemathics/apis/type/shared/v1/trade_and_book.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a,systemathics/apis/type/shared/v1/trade.proto\x1a+systemathics/apis/type/shared/v1/book.proto\"\xc2\x01\n\x0cTradeAndBook\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x05trade\x18\x03 \x01(\x0b\x32\'.systemathics.apis.type.shared.v1.Trade\x12\x39\n\x04\x62ook\x18\x04 \x01(\x0b\x32+.systemathics.apis.type.shared.v1.BookLimitb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2.DESCRIPTOR,])




_TRADEANDBOOK = _descriptor.Descriptor(
  name='TradeAndBook',
  full_name='systemathics.apis.type.shared.v1.TradeAndBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.type.shared.v1.TradeAndBook.mapping', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.type.shared.v1.TradeAndBook.time_stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade', full_name='systemathics.apis.type.shared.v1.TradeAndBook.trade', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='book', full_name='systemathics.apis.type.shared.v1.TradeAndBook.book', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=461,
)

_TRADEANDBOOK.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRADEANDBOOK.fields_by_name['trade'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2._TRADE
_TRADEANDBOOK.fields_by_name['book'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2._BOOKLIMIT
DESCRIPTOR.message_types_by_name['TradeAndBook'] = _TRADEANDBOOK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TradeAndBook = _reflection.GeneratedProtocolMessageType('TradeAndBook', (_message.Message,), {
  'DESCRIPTOR' : _TRADEANDBOOK,
  '__module__' : 'systemathics.apis.type.shared.v1.trade_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.TradeAndBook)
  })
_sym_db.RegisterMessage(TradeAndBook)


# @@protoc_insertion_point(module_scope)
