# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick_analytics/v1/tick_bollinger.proto',
  package='systemathics.apis.services.tick_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAsystemathics/apis/services/tick_analytics/v1/tick_bollinger.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xc3\x03\n\x14TickBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12K\n\x05\x66ield\x18\x03 \x01(\x0e\x32<.systemathics.apis.services.tick_analytics.v1.BollingerPrice\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x11\n\tdeviation\x18\x05 \x01(\x01\x12)\n\x06period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08sampling\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\t \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\n \x03(\t\x12\x0e\n\x06reject\x18\x0b \x03(\t\"\xde\x01\n\x15TickBollingerResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue*~\n\x0e\x42ollingerPrice\x12\x1f\n\x1b\x42OLLINGER_PRICE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x42OLLINGER_PRICE_TRADE\x10\x01\x12\x17\n\x13\x42OLLINGER_PRICE_BID\x10\x02\x12\x17\n\x13\x42OLLINGER_PRICE_ASK\x10\x03\x32\xb3\x01\n\x14TickBollingerService\x12\x9a\x01\n\rTickBollinger\x12\x42.systemathics.apis.services.tick_analytics.v1.TickBollingerRequest\x1a\x43.systemathics.apis.services.tick_analytics.v1.TickBollingerResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_BOLLINGERPRICE = _descriptor.EnumDescriptor(
  name='BollingerPrice',
  full_name='systemathics.apis.services.tick_analytics.v1.BollingerPrice',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_TRADE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_BID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOLLINGER_PRICE_ASK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=994,
  serialized_end=1120,
)
_sym_db.RegisterEnumDescriptor(_BOLLINGERPRICE)

BollingerPrice = enum_type_wrapper.EnumTypeWrapper(_BOLLINGERPRICE)
BOLLINGER_PRICE_UNSPECIFIED = 0
BOLLINGER_PRICE_TRADE = 1
BOLLINGER_PRICE_BID = 2
BOLLINGER_PRICE_ASK = 3



_TICKBOLLINGERREQUEST = _descriptor.Descriptor(
  name='TickBollingerRequest',
  full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.field', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.length', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviation', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.deviation', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.period', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.offset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.sampling', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.adjustment', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.accept', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reject', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerRequest.reject', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=767,
)


_TICKBOLLINGERRESPONSE = _descriptor.Descriptor(
  name='TickBollingerResponse',
  full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.lower', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.upper', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middle', full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerResponse.middle', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=992,
)

_TICKBOLLINGERREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKBOLLINGERREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKBOLLINGERREQUEST.fields_by_name['field'].enum_type = _BOLLINGERPRICE
_TICKBOLLINGERREQUEST.fields_by_name['period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKBOLLINGERREQUEST.fields_by_name['offset'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKBOLLINGERREQUEST.fields_by_name['sampling'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKBOLLINGERRESPONSE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICKBOLLINGERRESPONSE.fields_by_name['lower'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TICKBOLLINGERRESPONSE.fields_by_name['upper'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TICKBOLLINGERRESPONSE.fields_by_name['middle'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['TickBollingerRequest'] = _TICKBOLLINGERREQUEST
DESCRIPTOR.message_types_by_name['TickBollingerResponse'] = _TICKBOLLINGERRESPONSE
DESCRIPTOR.enum_types_by_name['BollingerPrice'] = _BOLLINGERPRICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickBollingerRequest = _reflection.GeneratedProtocolMessageType('TickBollingerRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerRequest)
  })
_sym_db.RegisterMessage(TickBollingerRequest)

TickBollingerResponse = _reflection.GeneratedProtocolMessageType('TickBollingerResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOLLINGERRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickBollingerResponse)
  })
_sym_db.RegisterMessage(TickBollingerResponse)



_TICKBOLLINGERSERVICE = _descriptor.ServiceDescriptor(
  name='TickBollingerService',
  full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1123,
  serialized_end=1302,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickBollinger',
    full_name='systemathics.apis.services.tick_analytics.v1.TickBollingerService.TickBollinger',
    index=0,
    containing_service=None,
    input_type=_TICKBOLLINGERREQUEST,
    output_type=_TICKBOLLINGERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKBOLLINGERSERVICE)

DESCRIPTOR.services_by_name['TickBollingerService'] = _TICKBOLLINGERSERVICE

# @@protoc_insertion_point(module_scope)
