# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_raw.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick/v1/tick_raw.proto',
  package='systemathics.apis.services.tick.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1systemathics/apis/services/tick/v1/tick_raw.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xce\x01\n\x0eTickRawRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x36\n\x05level\x18\x03 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\"l\n\x0bTickRawItem\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x0e\n\x06source\x18\x03 \x01(\r\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"U\n\x0fTickRawResponse\x12\x42\n\traw_items\x18\x01 \x03(\x0b\x32/.systemathics.apis.services.tick.v1.TickRawItem\"q\n\x10TickRawResponse2\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x0e\n\x06source\x18\x03 \x01(\r\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x32\x86\x01\n\x0eTickRawService\x12t\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v1.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v1.TickRawResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TICKRAWREQUEST = _descriptor.Descriptor(
  name='TickRawRequest',
  full_name='systemathics.apis.services.tick.v1.TickRawRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick.v1.TickRawRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick.v1.TickRawRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='systemathics.apis.services.tick.v1.TickRawRequest.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=478,
)


_TICKRAWITEM = _descriptor.Descriptor(
  name='TickRawItem',
  full_name='systemathics.apis.services.tick.v1.TickRawItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick.v1.TickRawItem.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.tick.v1.TickRawItem.type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='systemathics.apis.services.tick.v1.TickRawItem.source', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickRawItem.payload', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=588,
)


_TICKRAWRESPONSE = _descriptor.Descriptor(
  name='TickRawResponse',
  full_name='systemathics.apis.services.tick.v1.TickRawResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_items', full_name='systemathics.apis.services.tick.v1.TickRawResponse.raw_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=675,
)


_TICKRAWRESPONSE2 = _descriptor.Descriptor(
  name='TickRawResponse2',
  full_name='systemathics.apis.services.tick.v1.TickRawResponse2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.source', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickRawResponse2.payload', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=790,
)

_TICKRAWREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKRAWREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKRAWREQUEST.fields_by_name['level'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2._LEVEL
_TICKRAWITEM.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICKRAWRESPONSE.fields_by_name['raw_items'].message_type = _TICKRAWITEM
_TICKRAWRESPONSE2.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['TickRawRequest'] = _TICKRAWREQUEST
DESCRIPTOR.message_types_by_name['TickRawItem'] = _TICKRAWITEM
DESCRIPTOR.message_types_by_name['TickRawResponse'] = _TICKRAWRESPONSE
DESCRIPTOR.message_types_by_name['TickRawResponse2'] = _TICKRAWRESPONSE2
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickRawRequest = _reflection.GeneratedProtocolMessageType('TickRawRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawRequest)
  })
_sym_db.RegisterMessage(TickRawRequest)

TickRawItem = _reflection.GeneratedProtocolMessageType('TickRawItem', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWITEM,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawItem)
  })
_sym_db.RegisterMessage(TickRawItem)

TickRawResponse = _reflection.GeneratedProtocolMessageType('TickRawResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse)
  })
_sym_db.RegisterMessage(TickRawResponse)

TickRawResponse2 = _reflection.GeneratedProtocolMessageType('TickRawResponse2', (_message.Message,), {
  'DESCRIPTOR' : _TICKRAWRESPONSE2,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_raw_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickRawResponse2)
  })
_sym_db.RegisterMessage(TickRawResponse2)



_TICKRAWSERVICE = _descriptor.ServiceDescriptor(
  name='TickRawService',
  full_name='systemathics.apis.services.tick.v1.TickRawService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=793,
  serialized_end=927,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickRaw',
    full_name='systemathics.apis.services.tick.v1.TickRawService.TickRaw',
    index=0,
    containing_service=None,
    input_type=_TICKRAWREQUEST,
    output_type=_TICKRAWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKRAWSERVICE)

DESCRIPTOR.services_by_name['TickRawService'] = _TICKRAWSERVICE

# @@protoc_insertion_point(module_scope)
