# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/market_book_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import side_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/market_book_updates.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:systemathics/apis/type/shared/v1/market_book_updates.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a-systemathics/apis/type/shared/v1/action.proto\x1a+systemathics/apis/type/shared/v1/side.proto\"m\n\x11MarketBookUpdates\x12\x13\n\x0bis_snapshot\x18\x01 \x01(\x08\x12\x43\n\x07updates\x18\x02 \x03(\x0b\x32\x32.systemathics.apis.type.shared.v1.MarketBookUpdate\"\xe9\x01\n\x10MarketBookUpdate\x12\x38\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.Action\x12\x34\n\x04side\x18\x02 \x01(\x0e\x32&.systemathics.apis.type.shared.v1.Side\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\r\x12)\n\x04size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12+\n\x05price\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2.DESCRIPTOR,])




_MARKETBOOKUPDATES = _descriptor.Descriptor(
  name='MarketBookUpdates',
  full_name='systemathics.apis.type.shared.v1.MarketBookUpdates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_snapshot', full_name='systemathics.apis.type.shared.v1.MarketBookUpdates.is_snapshot', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='systemathics.apis.type.shared.v1.MarketBookUpdates.updates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=329,
)


_MARKETBOOKUPDATE = _descriptor.Descriptor(
  name='MarketBookUpdate',
  full_name='systemathics.apis.type.shared.v1.MarketBookUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.side', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.depth', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.size', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='systemathics.apis.type.shared.v1.MarketBookUpdate.price', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=565,
)

_MARKETBOOKUPDATES.fields_by_name['updates'].message_type = _MARKETBOOKUPDATE
_MARKETBOOKUPDATE.fields_by_name['action'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2._ACTION
_MARKETBOOKUPDATE.fields_by_name['side'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_side__pb2._SIDE
_MARKETBOOKUPDATE.fields_by_name['size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MARKETBOOKUPDATE.fields_by_name['price'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['MarketBookUpdates'] = _MARKETBOOKUPDATES
DESCRIPTOR.message_types_by_name['MarketBookUpdate'] = _MARKETBOOKUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketBookUpdates = _reflection.GeneratedProtocolMessageType('MarketBookUpdates', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBOOKUPDATES,
  '__module__' : 'systemathics.apis.type.shared.v1.market_book_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketBookUpdates)
  })
_sym_db.RegisterMessage(MarketBookUpdates)

MarketBookUpdate = _reflection.GeneratedProtocolMessageType('MarketBookUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MARKETBOOKUPDATE,
  '__module__' : 'systemathics.apis.type.shared.v1.market_book_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketBookUpdate)
  })
_sym_db.RegisterMessage(MarketBookUpdate)


# @@protoc_insertion_point(module_scope)
