# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import mappings_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2
from systemathics.apis.type.shared.v1 import market_fields_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick/v1/tick_updates.proto',
  package='systemathics.apis.services.tick.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5systemathics/apis/services/tick/v1/tick_updates.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/mappings.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a:systemathics/apis/type/shared/v1/market_book_updates.proto\x1a<systemathics/apis/type/shared/v1/market_fields_updates.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xd3\x01\n\x12TickUpdatesRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x36\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\xc4\x02\n\x13TickUpdatesResponse\x12\x14\n\x0c\x65vent_source\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12O\n\x0e\x66ields_updates\x18\x03 \x01(\x0b\x32\x35.systemathics.apis.type.shared.v1.MarketFieldsUpdatesH\x00\x12K\n\x0c\x62ook_updates\x18\x04 \x01(\x0b\x32\x33.systemathics.apis.type.shared.v1.MarketBookUpdatesH\x00\x12>\n\x08mappings\x18\x05 \x01(\x0b\x32*.systemathics.apis.type.shared.v1.MappingsH\x00\x42\t\n\x07payload2\x97\x01\n\x12TickUpdatesService\x12\x80\x01\n\x0bTickUpdates\x12\x36.systemathics.apis.services.tick.v1.TickUpdatesRequest\x1a\x37.systemathics.apis.services.tick.v1.TickUpdatesResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TICKUPDATESREQUEST = _descriptor.Descriptor(
  name='TickUpdatesRequest',
  full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifiers', full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest.identifiers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick.v1.TickUpdatesRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=658,
)


_TICKUPDATESRESPONSE = _descriptor.Descriptor(
  name='TickUpdatesResponse',
  full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_source', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.event_source', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.time_stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields_updates', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.fields_updates', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='book_updates', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.book_updates', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mappings', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.mappings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickUpdatesResponse.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=661,
  serialized_end=985,
)

_TICKUPDATESREQUEST.fields_by_name['identifiers'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKUPDATESREQUEST.fields_by_name['level'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2._LEVEL
_TICKUPDATESREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKUPDATESRESPONSE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICKUPDATESRESPONSE.fields_by_name['fields_updates'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2._MARKETFIELDSUPDATES
_TICKUPDATESRESPONSE.fields_by_name['book_updates'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2._MARKETBOOKUPDATES
_TICKUPDATESRESPONSE.fields_by_name['mappings'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2._MAPPINGS
_TICKUPDATESRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKUPDATESRESPONSE.fields_by_name['fields_updates'])
_TICKUPDATESRESPONSE.fields_by_name['fields_updates'].containing_oneof = _TICKUPDATESRESPONSE.oneofs_by_name['payload']
_TICKUPDATESRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKUPDATESRESPONSE.fields_by_name['book_updates'])
_TICKUPDATESRESPONSE.fields_by_name['book_updates'].containing_oneof = _TICKUPDATESRESPONSE.oneofs_by_name['payload']
_TICKUPDATESRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKUPDATESRESPONSE.fields_by_name['mappings'])
_TICKUPDATESRESPONSE.fields_by_name['mappings'].containing_oneof = _TICKUPDATESRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['TickUpdatesRequest'] = _TICKUPDATESREQUEST
DESCRIPTOR.message_types_by_name['TickUpdatesResponse'] = _TICKUPDATESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickUpdatesRequest = _reflection.GeneratedProtocolMessageType('TickUpdatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesRequest)
  })
_sym_db.RegisterMessage(TickUpdatesRequest)

TickUpdatesResponse = _reflection.GeneratedProtocolMessageType('TickUpdatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKUPDATESRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickUpdatesResponse)
  })
_sym_db.RegisterMessage(TickUpdatesResponse)



_TICKUPDATESSERVICE = _descriptor.ServiceDescriptor(
  name='TickUpdatesService',
  full_name='systemathics.apis.services.tick.v1.TickUpdatesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=988,
  serialized_end=1139,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickUpdates',
    full_name='systemathics.apis.services.tick.v1.TickUpdatesService.TickUpdates',
    index=0,
    containing_service=None,
    input_type=_TICKUPDATESREQUEST,
    output_type=_TICKUPDATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKUPDATESSERVICE)

DESCRIPTOR.services_by_name['TickUpdatesService'] = _TICKUPDATESSERVICE

# @@protoc_insertion_point(module_scope)
