# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/topology/v1/topologies.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/topology/v1/topologies.proto',
  package='systemathics.apis.services.topology.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7systemathics/apis/services/topology/v1/topologies.proto\x12&systemathics.apis.services.topology.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a,systemathics/apis/type/shared/v1/level.proto\"\xb7\x02\n\x11TopologiesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x36\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\x12P\n\x0bgranularity\x18\x03 \x01(\x0e\x32;.systemathics.apis.services.topology.v1.TopologyGranularity\x12*\n\x05start\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"f\n\rTopologyEntry\x12 \n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x1e\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12\x13\n\x0bticks_count\x18\x03 \x01(\x04\"n\n\x12TopologiesResponse\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.topology.v1.TopologyEntry\x12\x10\n\x08has_more\x18\x02 \x01(\x08*\xe2\x01\n\x13TopologyGranularity\x12$\n TOPOLOGY_GRANULARITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTOPOLOGY_GRANULARITY_DAILY\x10\x01\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_WEEKLY\x10\x02\x12 \n\x1cTOPOLOGY_GRANULARITY_MONTHLY\x10\x03\x12!\n\x1dTOPOLOGY_GRANULARITY_QUATERLY\x10\x04\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_YEARLY\x10\x05\x32\x99\x01\n\x11TopologiesService\x12\x83\x01\n\nTopologies\x12\x39.systemathics.apis.services.topology.v1.TopologiesRequest\x1a:.systemathics.apis.services.topology.v1.TopologiesResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,])

_TOPOLOGYGRANULARITY = _descriptor.EnumDescriptor(
  name='TopologyGranularity',
  full_name='systemathics.apis.services.topology.v1.TopologyGranularity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_DAILY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_WEEKLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_MONTHLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_QUATERLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_YEARLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=783,
  serialized_end=1009,
)
_sym_db.RegisterEnumDescriptor(_TOPOLOGYGRANULARITY)

TopologyGranularity = enum_type_wrapper.EnumTypeWrapper(_TOPOLOGYGRANULARITY)
TOPOLOGY_GRANULARITY_UNSPECIFIED = 0
TOPOLOGY_GRANULARITY_DAILY = 1
TOPOLOGY_GRANULARITY_WEEKLY = 2
TOPOLOGY_GRANULARITY_MONTHLY = 3
TOPOLOGY_GRANULARITY_QUATERLY = 4
TOPOLOGY_GRANULARITY_YEARLY = 5



_TOPOLOGIESREQUEST = _descriptor.Descriptor(
  name='TopologiesRequest',
  full_name='systemathics.apis.services.topology.v1.TopologiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granularity', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.granularity', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.count', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=564,
)


_TOPOLOGYENTRY = _descriptor.Descriptor(
  name='TopologyEntry',
  full_name='systemathics.apis.services.topology.v1.TopologyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin', full_name='systemathics.apis.services.topology.v1.TopologyEntry.begin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='systemathics.apis.services.topology.v1.TopologyEntry.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticks_count', full_name='systemathics.apis.services.topology.v1.TopologyEntry.ticks_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=668,
)


_TOPOLOGIESRESPONSE = _descriptor.Descriptor(
  name='TopologiesResponse',
  full_name='systemathics.apis.services.topology.v1.TopologiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='systemathics.apis.services.topology.v1.TopologiesResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_more', full_name='systemathics.apis.services.topology.v1.TopologiesResponse.has_more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=670,
  serialized_end=780,
)

_TOPOLOGIESREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TOPOLOGIESREQUEST.fields_by_name['level'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2._LEVEL
_TOPOLOGIESREQUEST.fields_by_name['granularity'].enum_type = _TOPOLOGYGRANULARITY
_TOPOLOGIESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_TOPOLOGIESREQUEST.fields_by_name['count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_TOPOLOGYENTRY.fields_by_name['begin'].message_type = google_dot_type_dot_date__pb2._DATE
_TOPOLOGYENTRY.fields_by_name['end'].message_type = google_dot_type_dot_date__pb2._DATE
_TOPOLOGIESRESPONSE.fields_by_name['entries'].message_type = _TOPOLOGYENTRY
DESCRIPTOR.message_types_by_name['TopologiesRequest'] = _TOPOLOGIESREQUEST
DESCRIPTOR.message_types_by_name['TopologyEntry'] = _TOPOLOGYENTRY
DESCRIPTOR.message_types_by_name['TopologiesResponse'] = _TOPOLOGIESRESPONSE
DESCRIPTOR.enum_types_by_name['TopologyGranularity'] = _TOPOLOGYGRANULARITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopologiesRequest = _reflection.GeneratedProtocolMessageType('TopologiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESREQUEST,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesRequest)
  })
_sym_db.RegisterMessage(TopologiesRequest)

TopologyEntry = _reflection.GeneratedProtocolMessageType('TopologyEntry', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYENTRY,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologyEntry)
  })
_sym_db.RegisterMessage(TopologyEntry)

TopologiesResponse = _reflection.GeneratedProtocolMessageType('TopologiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESRESPONSE,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesResponse)
  })
_sym_db.RegisterMessage(TopologiesResponse)



_TOPOLOGIESSERVICE = _descriptor.ServiceDescriptor(
  name='TopologiesService',
  full_name='systemathics.apis.services.topology.v1.TopologiesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1012,
  serialized_end=1165,
  methods=[
  _descriptor.MethodDescriptor(
    name='Topologies',
    full_name='systemathics.apis.services.topology.v1.TopologiesService.Topologies',
    index=0,
    containing_service=None,
    input_type=_TOPOLOGIESREQUEST,
    output_type=_TOPOLOGIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TOPOLOGIESSERVICE)

DESCRIPTOR.services_by_name['TopologiesService'] = _TOPOLOGIESSERVICE

# @@protoc_insertion_point(module_scope)
