# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/time_interval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/time_interval.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4systemathics/apis/type/shared/v1/time_interval.proto\x12 systemathics.apis.type.shared.v1\x1a\x1bgoogle/type/timeofday.proto\"d\n\x0cTimeInterval\x12*\n\nstart_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12(\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_timeofday__pb2.DESCRIPTOR,])




_TIMEINTERVAL = _descriptor.Descriptor(
  name='TimeInterval',
  full_name='systemathics.apis.type.shared.v1.TimeInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='systemathics.apis.type.shared.v1.TimeInterval.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='systemathics.apis.type.shared.v1.TimeInterval.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=219,
)

_TIMEINTERVAL.fields_by_name['start_time'].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
_TIMEINTERVAL.fields_by_name['end_time'].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
DESCRIPTOR.message_types_by_name['TimeInterval'] = _TIMEINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeInterval = _reflection.GeneratedProtocolMessageType('TimeInterval', (_message.Message,), {
  'DESCRIPTOR' : _TIMEINTERVAL,
  '__module__' : 'systemathics.apis.type.shared.v1.time_interval_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.TimeInterval)
  })
_sym_db.RegisterMessage(TimeInterval)


# @@protoc_insertion_point(module_scope)
