# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/static_data/v1/static_data.proto',
  package='systemathics.apis.services.static_data.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xbb\x04\n\x11StaticDataRequest\x12H\n\nasset_type\x18\x01 \x01(\x0e\x32\x34.systemathics.apis.services.static_data.v1.AssetType\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65xchange\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06ticker\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_contract\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_category\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\requity_sector\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05index\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ode\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x05start\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xb2\x02\n\x12StaticDataResponse\x12G\n\x07\x66utures\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntry\x12H\n\x08\x65quities\x18\x02 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntry\x12\x41\n\x04\x65tfs\x18\x03 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.EtfEntry\x12\x46\n\x07indices\x18\x04 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.IndexEntry\"\x8b\x05\n\x0b\x45quityEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12T\n\x07mapping\x18\x08 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x0c\n\x04isin\x18\x0f \x01(\t\x12\r\n\x05\x63usip\x18\x10 \x01(\t\x12\r\n\x05sedol\x18\x11 \x01(\t\x12T\n\x07sectors\x18\x12 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x05\n\x08\x45tfEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12Q\n\x07mapping\x18\x08 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x0c\n\x04isin\x18\x0f \x01(\t\x12\r\n\x05\x63usip\x18\x10 \x01(\t\x12\r\n\x05sedol\x18\x11 \x01(\t\x12Q\n\x07sectors\x18\x12 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x05\n\x0b\x46utureEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12T\n\x07mapping\x18\x08 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x12\n\nunderlying\x18\x0f \x01(\t\x12\x10\n\x08\x63ontract\x18\x10 \x01(\t\x12V\n\x08\x63\x61tegory\x18\x11 \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry\x12\r\n\x05\x63hain\x18\x12 \x01(\t\x12#\n\x08maturity\x18\x13 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05month\x18\x14 \x01(\t\x12\x0c\n\x04year\x18\x15 \x01(\x05\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rCategoryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x03\n\nIndexEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12S\n\x07mapping\x18\x08 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x0f \x01(\t\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\x93\x01\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x32\x9f\x01\n\x11StaticDataService\x12\x89\x01\n\nStaticData\x12<.systemathics.apis.services.static_data.v1.StaticDataRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])

_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='systemathics.apis.services.static_data.v1.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_ALL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_EQUITY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_FUTURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_ETF', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_INDEX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3515,
  serialized_end=3662,
)
_sym_db.RegisterEnumDescriptor(_ASSETTYPE)

AssetType = enum_type_wrapper.EnumTypeWrapper(_ASSETTYPE)
ASSET_TYPE_UNSPECIFIED = 0
ASSET_TYPE_ALL = 1
ASSET_TYPE_EQUITY = 2
ASSET_TYPE_FUTURE = 3
ASSET_TYPE_ETF = 4
ASSET_TYPE_INDEX = 5



_STATICDATAREQUEST = _descriptor.Descriptor(
  name='StaticDataRequest',
  full_name='systemathics.apis.services.static_data.v1.StaticDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_type', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.asset_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.exchange', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.ticker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future_contract', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.future_contract', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future_category', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.future_category', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='equity_sector', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.equity_sector', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.index', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.code', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.start', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.count', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=785,
)


_STATICDATARESPONSE = _descriptor.Descriptor(
  name='StaticDataResponse',
  full_name='systemathics.apis.services.static_data.v1.StaticDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='futures', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.futures', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='equities', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.equities', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etfs', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.etfs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indices', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.indices', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=1094,
)


_EQUITYENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_EQUITYENTRY_SECTORSENTRY = _descriptor.Descriptor(
  name='SectorsEntry',
  full_name='systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1748,
)

_EQUITYENTRY = _descriptor.Descriptor(
  name='EquityEntry',
  full_name='systemathics.apis.services.static_data.v1.EquityEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.EquityEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.EquityEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.EquityEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.EquityEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.EquityEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.EquityEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.EquityEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.EquityEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.EquityEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.EquityEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.EquityEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.EquityEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.EquityEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.EquityEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isin', full_name='systemathics.apis.services.static_data.v1.EquityEntry.isin', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cusip', full_name='systemathics.apis.services.static_data.v1.EquityEntry.cusip', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sedol', full_name='systemathics.apis.services.static_data.v1.EquityEntry.sedol', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sectors', full_name='systemathics.apis.services.static_data.v1.EquityEntry.sectors', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capitalization', full_name='systemathics.apis.services.static_data.v1.EquityEntry.capitalization', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EQUITYENTRY_MAPPINGENTRY, _EQUITYENTRY_SECTORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1748,
)


_ETFENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_ETFENTRY_SECTORSENTRY = _descriptor.Descriptor(
  name='SectorsEntry',
  full_name='systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1748,
)

_ETFENTRY = _descriptor.Descriptor(
  name='EtfEntry',
  full_name='systemathics.apis.services.static_data.v1.EtfEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.EtfEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.EtfEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.EtfEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.EtfEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.EtfEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.EtfEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.EtfEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.EtfEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.EtfEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.EtfEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.EtfEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.EtfEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.EtfEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.EtfEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isin', full_name='systemathics.apis.services.static_data.v1.EtfEntry.isin', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cusip', full_name='systemathics.apis.services.static_data.v1.EtfEntry.cusip', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sedol', full_name='systemathics.apis.services.static_data.v1.EtfEntry.sedol', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sectors', full_name='systemathics.apis.services.static_data.v1.EtfEntry.sectors', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capitalization', full_name='systemathics.apis.services.static_data.v1.EtfEntry.capitalization', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ETFENTRY_MAPPINGENTRY, _ETFENTRY_SECTORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1751,
  serialized_end=2393,
)


_FUTUREENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_FUTUREENTRY_CATEGORYENTRY = _descriptor.Descriptor(
  name='CategoryEntry',
  full_name='systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3024,
  serialized_end=3071,
)

_FUTUREENTRY = _descriptor.Descriptor(
  name='FutureEntry',
  full_name='systemathics.apis.services.static_data.v1.FutureEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.FutureEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.FutureEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.FutureEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.FutureEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.FutureEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.FutureEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.FutureEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.FutureEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.FutureEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.FutureEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.FutureEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.FutureEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.FutureEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.FutureEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='underlying', full_name='systemathics.apis.services.static_data.v1.FutureEntry.underlying', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='systemathics.apis.services.static_data.v1.FutureEntry.contract', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='systemathics.apis.services.static_data.v1.FutureEntry.category', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='systemathics.apis.services.static_data.v1.FutureEntry.chain', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maturity', full_name='systemathics.apis.services.static_data.v1.FutureEntry.maturity', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='systemathics.apis.services.static_data.v1.FutureEntry.month', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='systemathics.apis.services.static_data.v1.FutureEntry.year', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FUTUREENTRY_MAPPINGENTRY, _FUTUREENTRY_CATEGORYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2396,
  serialized_end=3071,
)


_INDEXENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_INDEXENTRY = _descriptor.Descriptor(
  name='IndexEntry',
  full_name='systemathics.apis.services.static_data.v1.IndexEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.IndexEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.IndexEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.IndexEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.IndexEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.IndexEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.IndexEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.IndexEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.IndexEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.IndexEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.IndexEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.IndexEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.IndexEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.IndexEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.IndexEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='systemathics.apis.services.static_data.v1.IndexEntry.description', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INDEXENTRY_MAPPINGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3074,
  serialized_end=3512,
)

_STATICDATAREQUEST.fields_by_name['asset_type'].enum_type = _ASSETTYPE
_STATICDATAREQUEST.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['exchange'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['ticker'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['future_contract'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['future_category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['equity_sector'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['index'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_STATICDATAREQUEST.fields_by_name['count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_STATICDATARESPONSE.fields_by_name['futures'].message_type = _FUTUREENTRY
_STATICDATARESPONSE.fields_by_name['equities'].message_type = _EQUITYENTRY
_STATICDATARESPONSE.fields_by_name['etfs'].message_type = _ETFENTRY
_STATICDATARESPONSE.fields_by_name['indices'].message_type = _INDEXENTRY
_EQUITYENTRY_MAPPINGENTRY.containing_type = _EQUITYENTRY
_EQUITYENTRY_SECTORSENTRY.containing_type = _EQUITYENTRY
_EQUITYENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_EQUITYENTRY.fields_by_name['mapping'].message_type = _EQUITYENTRY_MAPPINGENTRY
_EQUITYENTRY.fields_by_name['sectors'].message_type = _EQUITYENTRY_SECTORSENTRY
_EQUITYENTRY.fields_by_name['capitalization'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_ETFENTRY_MAPPINGENTRY.containing_type = _ETFENTRY
_ETFENTRY_SECTORSENTRY.containing_type = _ETFENTRY
_ETFENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_ETFENTRY.fields_by_name['mapping'].message_type = _ETFENTRY_MAPPINGENTRY
_ETFENTRY.fields_by_name['sectors'].message_type = _ETFENTRY_SECTORSENTRY
_ETFENTRY.fields_by_name['capitalization'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FUTUREENTRY_MAPPINGENTRY.containing_type = _FUTUREENTRY
_FUTUREENTRY_CATEGORYENTRY.containing_type = _FUTUREENTRY
_FUTUREENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_FUTUREENTRY.fields_by_name['mapping'].message_type = _FUTUREENTRY_MAPPINGENTRY
_FUTUREENTRY.fields_by_name['category'].message_type = _FUTUREENTRY_CATEGORYENTRY
_FUTUREENTRY.fields_by_name['maturity'].message_type = google_dot_type_dot_date__pb2._DATE
_INDEXENTRY_MAPPINGENTRY.containing_type = _INDEXENTRY
_INDEXENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INDEXENTRY.fields_by_name['mapping'].message_type = _INDEXENTRY_MAPPINGENTRY
DESCRIPTOR.message_types_by_name['StaticDataRequest'] = _STATICDATAREQUEST
DESCRIPTOR.message_types_by_name['StaticDataResponse'] = _STATICDATARESPONSE
DESCRIPTOR.message_types_by_name['EquityEntry'] = _EQUITYENTRY
DESCRIPTOR.message_types_by_name['EtfEntry'] = _ETFENTRY
DESCRIPTOR.message_types_by_name['FutureEntry'] = _FUTUREENTRY
DESCRIPTOR.message_types_by_name['IndexEntry'] = _INDEXENTRY
DESCRIPTOR.enum_types_by_name['AssetType'] = _ASSETTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StaticDataRequest = _reflection.GeneratedProtocolMessageType('StaticDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATICDATAREQUEST,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticDataRequest)
  })
_sym_db.RegisterMessage(StaticDataRequest)

StaticDataResponse = _reflection.GeneratedProtocolMessageType('StaticDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATICDATARESPONSE,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticDataResponse)
  })
_sym_db.RegisterMessage(StaticDataResponse)

EquityEntry = _reflection.GeneratedProtocolMessageType('EquityEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _EQUITYENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry)
    })
  ,

  'SectorsEntry' : _reflection.GeneratedProtocolMessageType('SectorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EQUITYENTRY_SECTORSENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry)
    })
  ,
  'DESCRIPTOR' : _EQUITYENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry)
  })
_sym_db.RegisterMessage(EquityEntry)
_sym_db.RegisterMessage(EquityEntry.MappingEntry)
_sym_db.RegisterMessage(EquityEntry.SectorsEntry)

EtfEntry = _reflection.GeneratedProtocolMessageType('EtfEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _ETFENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry)
    })
  ,

  'SectorsEntry' : _reflection.GeneratedProtocolMessageType('SectorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ETFENTRY_SECTORSENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry)
    })
  ,
  'DESCRIPTOR' : _ETFENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry)
  })
_sym_db.RegisterMessage(EtfEntry)
_sym_db.RegisterMessage(EtfEntry.MappingEntry)
_sym_db.RegisterMessage(EtfEntry.SectorsEntry)

FutureEntry = _reflection.GeneratedProtocolMessageType('FutureEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _FUTUREENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry)
    })
  ,

  'CategoryEntry' : _reflection.GeneratedProtocolMessageType('CategoryEntry', (_message.Message,), {
    'DESCRIPTOR' : _FUTUREENTRY_CATEGORYENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry)
    })
  ,
  'DESCRIPTOR' : _FUTUREENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry)
  })
_sym_db.RegisterMessage(FutureEntry)
_sym_db.RegisterMessage(FutureEntry.MappingEntry)
_sym_db.RegisterMessage(FutureEntry.CategoryEntry)

IndexEntry = _reflection.GeneratedProtocolMessageType('IndexEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _INDEXENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry)
    })
  ,
  'DESCRIPTOR' : _INDEXENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.IndexEntry)
  })
_sym_db.RegisterMessage(IndexEntry)
_sym_db.RegisterMessage(IndexEntry.MappingEntry)


_EQUITYENTRY_MAPPINGENTRY._options = None
_EQUITYENTRY_SECTORSENTRY._options = None
_ETFENTRY_MAPPINGENTRY._options = None
_ETFENTRY_SECTORSENTRY._options = None
_FUTUREENTRY_MAPPINGENTRY._options = None
_FUTUREENTRY_CATEGORYENTRY._options = None
_INDEXENTRY_MAPPINGENTRY._options = None

_STATICDATASERVICE = _descriptor.ServiceDescriptor(
  name='StaticDataService',
  full_name='systemathics.apis.services.static_data.v1.StaticDataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3665,
  serialized_end=3824,
  methods=[
  _descriptor.MethodDescriptor(
    name='StaticData',
    full_name='systemathics.apis.services.static_data.v1.StaticDataService.StaticData',
    index=0,
    containing_service=None,
    input_type=_STATICDATAREQUEST,
    output_type=_STATICDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATICDATASERVICE)

DESCRIPTOR.services_by_name['StaticDataService'] = _STATICDATASERVICE

# @@protoc_insertion_point(module_scope)
